Steam Community client.
The main client for interacting with Steam Community web endpoints.
Structs
- Client
JsToken - Token response from /chat/clientjstoken endpoint.
- Steam
Request Builder - A wrapper around request builder that automatically appends the session ID to POST data.
- Steam
User - Steam Community web client.
- Steam
User Builder - Builder for
SteamUser.