pub struct SteamRequestBuilder { /* private fields */ }Expand description
A wrapper around request builder that automatically appends the session ID to POST data.
Implementations
Sourceimpl SteamRequestBuilder
impl SteamRequestBuilder
Sourcepub fn form<T: Serialize + ?Sized>(self, form: &T) -> Self
pub fn form<T: Serialize + ?Sized>(self, form: &T) -> Self
Adds a form body to the request.
If a session ID is available, it is automatically injected as
sessionid and sessionID into the form data.
Sourcepub fn multipart(self, form: Form) -> Self
pub fn multipart(self, form: Form) -> Self
Adds a multipart form body to the request.
If a session ID is available, it is automatically appended to the multipart data.
Sourcepub fn query<T: Serialize + ?Sized>(self, query: &T) -> Self
pub fn query<T: Serialize + ?Sized>(self, query: &T) -> Self
Adds a query parameter to the request.
Sourcepub fn header<K, V>(self, key: K, value: V) -> Selfwhere
HeaderName: TryFrom<K>,
<HeaderName as TryFrom<K>>::Error: Into<Error>,
HeaderValue: TryFrom<V>,
<HeaderValue as TryFrom<V>>::Error: Into<Error>,
pub fn header<K, V>(self, key: K, value: V) -> Selfwhere
HeaderName: TryFrom<K>,
<HeaderName as TryFrom<K>>::Error: Into<Error>,
HeaderValue: TryFrom<V>,
<HeaderValue as TryFrom<V>>::Error: Into<Error>,
Adds a header to the request.