pub struct ActiveInventory {
pub app_id: u32,
pub game_icon: Option<String>,
pub game_name: String,
pub count: u32,
}Expand description
Represents an app that has items in the user’s inventory.
Fields
app_id: u32The Steam App ID (e.g., 730 for CS:GO, 440 for TF2).
game_icon: Option<String>URL to the game’s icon image.
game_name: StringThe display name of the game.
count: u32Number of items in the inventory for this app.