pub struct TradeOfferItems {
pub steamid: Option<SteamID>,
pub items: Vec<TradeOfferItem>,
}Expand description
Container for assets belonging to one side of a trade.
Fields
steamid: Option<SteamID>SteamID of the owner of these items. None if the data-miniprofile
attribute was missing or unparseable.
items: Vec<TradeOfferItem>List of items in this side of the trade.