Module container

Module container 

Detection of “container” inventory items (weapon cases, capsules, sticker packs, gifts, etc.).

Functions

is_inventory_container_item
Returns true when an inventory item is a container — a weapon case, capsule, sticker pack, gift, or other “openable” item.