pub struct FallbackSteamUser {
pub local: SteamUser,
}Expand description
A composite client that attempts requests across local, remote, and GAS clients sequentially.
Note: To keep things simple and unified across error types, the
SteamUserApi implementation for FallbackSteamUser returns
SteamUserError. If remote or gas fail, their errors are mapped to a
SteamUserError::Other.
Fields
local: SteamUserImplementations