pub struct Session {
pub steam_id: Option<SteamID>,
pub session_id: Option<String>,
/* private fields */
}Expand description
Session manager for Steam Community.
Handles cookies, session IDs, and authentication state.
Fields
steam_id: Option<SteamID>Current Steam ID if logged in.
session_id: Option<String>Session ID for CSRF protection.
Implementations
Sourceimpl Session
impl Session
Set cookies from string slice.
Cookies should be in the format “name=value” or full Set-Cookie format.
pub fn ensure_session_id(&mut self) -> &str
Sourcepub fn get_session_id(&mut self) -> &str
pub fn get_session_id(&mut self) -> &str
Get the session ID, ensuring one exists.
Get the raw cookie string.
Sourcepub fn get_steam_id(&self) -> SteamID
pub fn get_steam_id(&self) -> SteamID
Get the SteamID for the current session.
Sourcepub fn is_logged_in(&self) -> bool
pub fn is_logged_in(&self) -> bool
Check if the session appears to be logged in (has steam_id).
Sourcepub fn mobile_access_token(&self) -> Option<&str>
pub fn mobile_access_token(&self) -> Option<&str>
Get the mobile access token, if set.
Sourcepub fn access_token(&self) -> Option<&str>
pub fn access_token(&self) -> Option<&str>
Get the OAuth access token, if set.
Sourcepub fn refresh_token(&self) -> Option<&str>
pub fn refresh_token(&self) -> Option<&str>
Get the OAuth refresh token, if set.
Sourcepub fn set_mobile_access_token(&mut self, token: String)
pub fn set_mobile_access_token(&mut self, token: String)
Set the mobile access token for 2FA operations.
Sourcepub fn set_refresh_token(&mut self, token: String)
pub fn set_refresh_token(&mut self, token: String)
Set the refresh token for token enumeration and renewal.
Sourcepub fn set_access_token(&mut self, token: String)
pub fn set_access_token(&mut self, token: String)
Set the access token.
Sourcepub fn clear_profile_url(&self)
pub fn clear_profile_url(&self)
Clear the cached profile URL.